import React from 'react';
import { Stepper, Step, StepLabel, StepIconProps, Typography } from '@mui/material';
import AirplanemodeActiveIcon from '@mui/icons-material/AirplanemodeActive';
import StoreIcon from '@mui/icons-material/Store';
import RecycleIcon from '@mui/icons-material/Restore';
import { Dewar } from "../../openapi";

const ICON_STYLE = { width: 24, height: 24 };

// Define the possible statuses
type DewarStatus = 'In Preparation' | 'Ready for Shipping' | 'Shipped' | 'Not Arrived' | 'Arrived' | 'Returned' | 'Delayed';

// Inline SVG Component
const BottleIcon: React.FC<{ fill: string }> = ({ fill }) => (
    <svg fill={fill} height="24px" width="24px" version="1.1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 276.777 276.777">
        <path d="M190.886,82.273c-3.23-2.586-7.525-7.643-7.525-21.639V43h8.027V0h-106v43h8.027v17.635c0,11.66-1.891,17.93-6.524,21.639  c-21.813,17.459-31.121,36.748-31.121,64.5v100.088c0,16.496,13.42,29.916,29.916,29.916h105.405  c16.496,0,29.916-13.42,29.916-29.916V146.773C221.007,121.103,210.029,97.594,190.886,82.273z M191.007,246.777H85.77V146.773  c0-18.589,5.199-29.339,19.867-41.078c15.758-12.612,17.778-30.706,17.778-45.061V43h29.945v17.635  c0,19.927,6.318,35.087,18.779,45.061c11.99,9.597,18.867,24.568,18.867,41.078V246.777z"/>
    </svg>
);

// Define types for icons mapping.
const ICONS: { [key: number]: React.ReactElement } = {
    0: <BottleIcon fill="grey" />,
    1: <AirplanemodeActiveIcon style={{ ...ICON_STYLE, color: 'blue' }} />,  // 'Ready for Shipping' -> Active
    2: <StoreIcon style={ICON_STYLE} />,  // 'Not Arrived'
    3: <RecycleIcon style={ICON_STYLE} />,  // 'Returned'
    4: <AirplanemodeActiveIcon style={{ ...ICON_STYLE, color: 'green' }} />, // 'Shipped' - Active
    5: <AirplanemodeActiveIcon style={{ ...ICON_STYLE, color: 'orange' }} />, // 'Delayed'
};

// Define StepIconContainer to accept correct props and handle typing better.
interface StepIconContainerProps extends React.HTMLAttributes<HTMLDivElement> {
    color: string;
}

const StepIconContainer: React.FC<StepIconContainerProps> = ({ color, children, ...rest }) => (
    <div style={{ color }} {...rest}>
        {children}
    </div>
);

type StepIconComponentProps = {
    icon: number;
    dewar: Dewar;
} & StepIconProps;

const StepIconComponent = ({ icon, dewar, ...props }: StepIconComponentProps) => {
    const { iconIndex, color} = getIconProperties(icon, dewar);

    // Adjust icon color for the bottle especially since it's an SVG element
    const IconComponent = ICONS[iconIndex];
    const iconProps = iconIndex === 0 ? { fill: color } : {};

    return (
        <StepIconContainer color={color} {...props}>
            {IconComponent
                ? React.cloneElement(IconComponent, iconProps)
                : <Typography variant="body2" color="error">Invalid icon</Typography>
            }
        </StepIconContainer>
    );
};

// Extracted function to determine icon properties
const getIconProperties = (icon: number, dewar: Dewar) => {
    const status = dewar.status as DewarStatus;
    const iconIndex = status === 'Delayed' && icon === 1 ? 5 : icon;
    const color = determineIconColor(icon, status);
    const fill = status === 'In Preparation' ? color : undefined;
    return { iconIndex, color, fill };
};

const STATUS_TO_STEP: Record<DewarStatus, number> = {
    'In Preparation': 0,
    'Ready for Shipping': 1,
    'Shipped': 1,
    'Delayed': 1,
    'Not Arrived': 2,
    'Arrived': 2,
    'Returned': 3
};

const getStatusStepIndex = (status: DewarStatus): number => STATUS_TO_STEP[status];

const determineIconColor = (iconIndex: number, status: DewarStatus): string => {
    const statusIndex = getStatusStepIndex(status);
    if (status === 'Delayed' && iconIndex === 1) {
        return 'orange';
    }
    return iconIndex <= statusIndex ? (iconIndex === statusIndex ? (status === 'Shipped' ? 'green' : 'blue') : 'green') : 'grey';
};

// Define your steps
const steps = ['In-House', 'Transit', 'At SLS', 'Returned'];

const CustomStepper = ({ dewar }: { dewar: Dewar }) => {
    // Determine the current active step
    const activeStep = getStatusStepIndex(dewar.status as DewarStatus);

    return (
        <div style={{ display: 'flex', justifyContent: 'center', width: '100%' /* Or any other preferred width */, maxWidth: '600px', margin: '0 auto' }}>
            <Stepper alternativeLabel activeStep={activeStep} style={{ width: '100%' }}>
                {steps.map((label, index) => (
                    <Step key={label}>
                        <StepLabel
                            StepIconComponent={(stepProps) => <StepIconComponent {...stepProps} icon={index} dewar={dewar} />}
                        >
                            {label}
                        </StepLabel>
                        <Typography variant="body2">
                            {index === 0 ? dewar.ready_date :
                                index === 1 ? dewar.shipping_date :
                                    index === 2 ? dewar.arrival_date :
                                        index === 3 ? dewar.returning_date : ''}
                        </Typography>
                    </Step>
                ))}
            </Stepper>
        </div>
    );
};

export default CustomStepper;