import * as React from 'react';
import { useState } from 'react';
import {
    Dialog,
    DialogTitle,
    DialogContent,
    DialogActions,
    Button,
    Typography,
    IconButton,
    Box,
} from '@mui/material';
import CloseIcon from '@mui/icons-material/Close';
import DownloadIcon from '@mui/icons-material/Download';
import UploadFileIcon from '@mui/icons-material/UploadFile';
import logo from '../assets/Heidi-logo.png';

interface UploadDialogProps {
    open: boolean;
    onClose: () => void;
}

const UploadDialog: React.FC<UploadDialogProps> = ({ open, onClose }) => {
    const [uploadError, setUploadError] = useState<string | null>(null);
    const [fileSummary, setFileSummary] = useState<{
        dewars: number;
        pucks: number;
        samples: number;
    } | null>(null);

    const handleFileUpload = (event: React.ChangeEvent<HTMLInputElement>) => {
        const file = event.target.files?.[0];
        if (!file) {
            return;
        }

        // Reset the previous state
        setUploadError(null);
        setFileSummary(null);

        // Example file type check: only allow .xlsx files
        if (!file.name.endsWith('.xlsx')) {
            setUploadError('Invalid file format. Please upload an .xlsx file.');
            return;
        }

        // Simulate file reading and validation
        const reader = new FileReader();
        reader.onload = () => {
            // Here, parse the file content and validate
            // For the demo, we'll mock the summary
            const mockSummary = {
                dewars: 5,
                pucks: 10,
                samples: 100,
            };
            setFileSummary(mockSummary);
        };
        reader.onerror = () => {
            setUploadError('Failed to read the file. Please try again.');
        };
        reader.readAsArrayBuffer(file);
    };

    return (
        <Dialog open={open} onClose={onClose} fullWidth maxWidth="sm">
            <DialogTitle>
                <Box display="flex" justifyContent="space-between" alignItems="center">
                    <Typography variant="h6">Upload Sample Data Sheet</Typography>
                    <IconButton onClick={onClose}>
                        <CloseIcon />
                    </IconButton>
                </Box>
            </DialogTitle>
            <DialogContent dividers>
                <Box display="flex" flexDirection="column" alignItems="center" mb={2}>
                    <img
                        src={logo}
                        alt="Logo"
                        style={{ width: 200, marginBottom: 16 }}
                    />
                    <Typography variant="subtitle1">
                        Latest Spreadsheet Template Version 6
                    </Typography>
                    <Typography variant="body2" color="textSecondary">
                        Last update: October 18, 2024
                    </Typography>
                    <Button
                        variant="outlined"
                        startIcon={<DownloadIcon />}
                        href="/path/to/template.xlsx"
                        download
                        sx={{ mt: 1 }}
                    >
                        Download XLSX
                    </Button>
                    <Typography variant="subtitle1" sx={{ mt: 3 }}>
                        Latest Spreadsheet Instructions Version 2.3
                    </Typography>
                    <Typography variant="body2" color="textSecondary">
                        Last updated: October 18, 2024
                    </Typography>
                    <Button
                        variant="outlined"
                        startIcon={<DownloadIcon />}
                        href="/path/to/instructions.pdf"
                        download
                        sx={{ mt: 1 }}
                    >
                        Download PDF
                    </Button>
                </Box>
                <Box mt={3}>
                    <Button
                        variant="contained"
                        component="label"
                        startIcon={<UploadFileIcon />}
                    >
                        Choose a File
                        <input
                            type="file"
                            hidden
                            onChange={handleFileUpload}
                        />
                    </Button>
                    {uploadError && (
                        <Typography color="error" sx={{ mt: 2 }}>
                            {uploadError}
                        </Typography>
                    )}
                    {fileSummary && (
                        <Box mt={2}>
                            <Typography color="success.main">
                                File uploaded successfully!
                            </Typography>
                            <Typography variant="body1">
                                <strong>File Summary:</strong>
                            </Typography>
                            <Typography>Dewars: {fileSummary.dewars}</Typography>
                            <Typography>Pucks: {fileSummary.pucks}</Typography>
                            <Typography>Samples: {fileSummary.samples}</Typography>
                        </Box>
                    )}
                </Box>
            </DialogContent>
            <DialogActions>
                <Button onClick={onClose} color="primary">
                    Close
                </Button>
            </DialogActions>
        </Dialog>
    );
};

export default UploadDialog;
